# Auto-generated by Charmonizer. 
# DO NOT EDIT THIS FILE!!

package Charmony;
use strict;
use warnings;

my %defs;

sub config { \%defs }

# BuildEnv
$defs{'CC'} = 'cc';
$defs{'CFLAGS'} = ' -fno-common -DPERL_DARWIN -mmacosx-version-min=12.4 -fno-strict-aliasing -pipe -fstack-protector-strong -DPERL_USE_SAFE_PUTENV -I/Users/pkarman/perl5/perlbrew/perls/perl-5.36.0/lib/5.36.0/darwin-2level/CORE';
$defs{'EXTRA_CFLAGS'} = '-pedantic -Wall -Wextra -Wno-variadic-macros -Wno-overlength-strings -DPERL_GCC_PEDANTIC -std=gnu99 -D_GNU_SOURCE';

# DirManip
$defs{'HAS_DIRENT_H'} = undef;
$defs{'HAS_DIRENT_D_NAMLEN'} = undef;
$defs{'HAS_DIRENT_D_TYPE'} = undef;
$defs{'makedir(_dir, _mode)'} = 'mkdir(_dir, _mode)';
$defs{'MAKEDIR_MODE_IGNORED'} = '0';
$defs{'DIR_SEP'} = '"/"';
$defs{'DIR_SEP_CHAR'} = '\'/\'';
$defs{'REMOVE_ZAPS_DIRS'} = undef;

# Headers
$defs{'HAS_POSIX'} = undef;
$defs{'HAS_C89'} = undef;
$defs{'HAS_C90'} = undef;
$defs{'HAS_CPIO_H'} = undef;
$defs{'HAS_DIRENT_H'} = undef;
$defs{'HAS_FCNTL_H'} = undef;
$defs{'HAS_GRP_H'} = undef;
$defs{'HAS_PWD_H'} = undef;
$defs{'HAS_REGEX_H'} = undef;
$defs{'HAS_SCHED_H'} = undef;
$defs{'HAS_SYS_STAT_H'} = undef;
$defs{'HAS_SYS_TIME_H'} = undef;
$defs{'HAS_SYS_TIMES_H'} = undef;
$defs{'HAS_SYS_TYPES_H'} = undef;
$defs{'HAS_SYS_UTSNAME_H'} = undef;
$defs{'HAS_SYS_WAIT_H'} = undef;
$defs{'HAS_TAR_H'} = undef;
$defs{'HAS_TERMIOS_H'} = undef;
$defs{'HAS_UNISTD_H'} = undef;
$defs{'HAS_UTIME_H'} = undef;
$defs{'HAS_ASSERT_H'} = undef;
$defs{'HAS_CTYPE_H'} = undef;
$defs{'HAS_ERRNO_H'} = undef;
$defs{'HAS_FLOAT_H'} = undef;
$defs{'HAS_LIMITS_H'} = undef;
$defs{'HAS_LOCALE_H'} = undef;
$defs{'HAS_MATH_H'} = undef;
$defs{'HAS_SETJMP_H'} = undef;
$defs{'HAS_SIGNAL_H'} = undef;
$defs{'HAS_STDARG_H'} = undef;
$defs{'HAS_STDDEF_H'} = undef;
$defs{'HAS_STDIO_H'} = undef;
$defs{'HAS_STDLIB_H'} = undef;
$defs{'HAS_STRING_H'} = undef;
$defs{'HAS_TIME_H'} = undef;
$defs{'HAS_PTHREAD_H'} = undef;

# FuncMacro
$defs{'HAS_FUNC_MACRO'} = undef;
$defs{'FUNC_MACRO'} = '__func__';
$defs{'HAS_ISO_FUNC_MACRO'} = undef;
$defs{'HAS_GNUC_FUNC_MACRO'} = undef;
$defs{'INLINE'} = '__inline';

# Booleans
$defs{'HAS_STDBOOL_H'} = undef;

# Integers
$defs{'LITTLE_END'} = undef;
$defs{'HAS_INTTYPES_H'} = undef;
$defs{'HAS_STDINT_H'} = undef;
$defs{'HAS_LONG_LONG'} = undef;
$defs{'SIZEOF_CHAR'} = '1';
$defs{'SIZEOF_SHORT'} = '2';
$defs{'SIZEOF_INT'} = '4';
$defs{'SIZEOF_LONG'} = '8';
$defs{'SIZEOF_PTR'} = '8';
$defs{'SIZEOF_SIZE_T'} = '8';
$defs{'SIZEOF_LONG_LONG'} = '8';
$defs{'HAS_INT8_T'} = undef;
$defs{'HAS_INT16_T'} = undef;
$defs{'HAS_INT32_T'} = undef;
$defs{'HAS_INT64_T'} = undef;
$defs{'PTR_TO_I64(ptr)'} = '((int64_t)(uint64_t)(ptr))';
$defs{'U64_TO_DOUBLE(num)'} = '((double)(num))';

# IntegerTypes

# IntegerLimits

# IntegerLiterals

# IntegerFormatStrings

# Strings
$defs{'HAS_C99_SNPRINTF'} = undef;

# Memory
$defs{'HAS_SYS_MMAN_H'} = undef;
$defs{'HAS_ALLOCA_H'} = undef;
$defs{'alloca'} = 'alloca';

# SymbolVisibility
$defs{'EXPORT'} = '__attribute__ ((visibility ("default")))';
$defs{'IMPORT'} = undef;

# UnusedVars
$defs{'UNUSED_VAR(x)'} = '((void)x)';
$defs{'UNREACHABLE_RETURN(type)'} = 'return (type)0';

# VariadicMacros
$defs{'HAS_VARIADIC_MACROS'} = undef;
$defs{'HAS_ISO_VARIADIC_MACROS'} = undef;
$defs{'HAS_GNUC_VARIADIC_MACROS'} = undef;


1;

