#define CFC_TOKENTYPE_FILE_START                       1
#define CFC_TOKENTYPE_PARCEL                           2
#define CFC_TOKENTYPE_SEMICOLON                        3
#define CFC_TOKENTYPE_RIGHT_CURLY_BRACE                4
#define CFC_TOKENTYPE_CLASS                            5
#define CFC_TOKENTYPE_LEFT_CURLY_BRACE                 6
#define CFC_TOKENTYPE_VOID                             7
#define CFC_TOKENTYPE_VA_LIST                          8
#define CFC_TOKENTYPE_INTEGER_TYPE_NAME                9
#define CFC_TOKENTYPE_FLOAT_TYPE_NAME                 10
#define CFC_TOKENTYPE_IDENTIFIER                      11
#define CFC_TOKENTYPE_PUBLIC                          12
#define CFC_TOKENTYPE_CONST                           13
#define CFC_TOKENTYPE_NULLABLE                        14
#define CFC_TOKENTYPE_INCREMENTED                     15
#define CFC_TOKENTYPE_DECREMENTED                     16
#define CFC_TOKENTYPE_INERT                           17
#define CFC_TOKENTYPE_INLINE                          18
#define CFC_TOKENTYPE_ABSTRACT                        19
#define CFC_TOKENTYPE_FINAL                           20
#define CFC_TOKENTYPE_ASTERISK                        21
#define CFC_TOKENTYPE_LEFT_SQUARE_BRACKET             22
#define CFC_TOKENTYPE_RIGHT_SQUARE_BRACKET            23
#define CFC_TOKENTYPE_INTEGER_LITERAL                 24
#define CFC_TOKENTYPE_HEX_LITERAL                     25
#define CFC_TOKENTYPE_FLOAT_LITERAL                   26
#define CFC_TOKENTYPE_STRING_LITERAL                  27
#define CFC_TOKENTYPE_TRUE                            28
#define CFC_TOKENTYPE_FALSE                           29
#define CFC_TOKENTYPE_NULL                            30
#define CFC_TOKENTYPE_LEFT_PAREN                      31
#define CFC_TOKENTYPE_RIGHT_PAREN                     32
#define CFC_TOKENTYPE_COMMA                           33
#define CFC_TOKENTYPE_ELLIPSIS                        34
#define CFC_TOKENTYPE_EQUALS                          35
#define CFC_TOKENTYPE_SCOPE_OP                        36
#define CFC_TOKENTYPE_DOCUCOMMENT                     37
#define CFC_TOKENTYPE_INHERITS                        38
#define CFC_TOKENTYPE_NICKNAME                        39
#define CFC_TOKENTYPE_CBLOCK_START                    40
#define CFC_TOKENTYPE_CBLOCK_CLOSE                    41
#define CFC_TOKENTYPE_BLOB                            42
